@@ -78,10 +78,10 @@ pub struct Concat<'a, K: ?Sized, V: ?Sized, P: BTreePage<K, V>> {
 /// database, if present. Else, delete the entry for `(key, value)`,
 /// if present.
 pub fn del<
-    T: AllocPage + LoadPage + core::fmt::Debug,
-    K: Storable + ?Sized + core::fmt::Debug + PartialEq,
-    V: Storable + ?Sized + core::fmt::Debug + PartialEq,
-    P: BTreeMutPage<K, V> + core::fmt::Debug,
+    T: AllocPage + LoadPage,
+    K: Storable + ?Sized + PartialEq,
+    V: Storable + ?Sized + PartialEq,
+    P: BTreeMutPage<K, V>,
 >(
     txn: &mut T,
     db: &mut Db_<K, V, P>,
@@ -107,10 +107,10 @@ pub fn del<
 /// after this.
 #[doc(hidden)]
 pub fn del_at_cursor<
-    T: AllocPage + LoadPage + core::fmt::Debug,
-    K: Storable + ?Sized + core::fmt::Debug + PartialEq,
-    V: Storable + ?Sized + core::fmt::Debug,
-    P: BTreeMutPage<K, V> + core::fmt::Debug,
+    T: AllocPage + LoadPage,
+    K: Storable + ?Sized + PartialEq,
+    V: Storable + ?Sized,
+    P: BTreeMutPage<K, V>,
 >(
     txn: &mut T,
     db: &mut Db_<K, V, P>,
@@ -284,7 +284,7 @@ fn concat<
     T: AllocPage + LoadPage,
     K: Storable + ?Sized,
     V: Storable + ?Sized,
-    P: BTreeMutPage<K, V> + core::fmt::Debug,
+    P: BTreeMutPage<K, V>,
 >(
     txn: &mut T,
     cursor: &mut Cursor<K, V, P>,
@@ -640,10 +640,10 @@ fn modify_rc<
 }
 
 fn update_root<
-    T: AllocPage + LoadPage + core::fmt::Debug,
-    K: Storable + ?Sized + core::fmt::Debug,
-    V: Storable + ?Sized + core::fmt::Debug,
-    P: BTreeMutPage<K, V> + core::fmt::Debug,
+    T: AllocPage + LoadPage,
+    K: Storable + ?Sized,
+    V: Storable + ?Sized,
+    P: BTreeMutPage<K, V>,
 >(
     txn: &mut T,
     db: &mut Db_<K, V, P>,
