@@ -107,8 +107,8 @@ impl<K: Storable, V: Storable> super::BTreePage<K, V> for Page<K, V> {
     //
     // Another thing to note is that -1 and `c.total` are valid
     // positions for a cursor `c`. The reason for this is that
-    // position `-1` has a right child (which is the left child of the
-    // first element).
+    // position `-1` has a right child (which is the first element's
+    // left child).
 
     type Cursor = PageCursor;
 
@@ -139,24 +139,20 @@ impl<K: Storable, V: Storable> super::BTreePage<K, V> for Page<K, V> {
         )
     }
     fn move_next(c: &mut Self::Cursor) -> bool {
-        if c.cur < c.total as isize {
-            c.cur += 1;
-            true
-        } else {
-            false
+        if c.cur >= c.total as isize {
+            return false;
         }
+        c.cur += 1;
+        true
     }
     fn move_prev(c: &mut Self::Cursor) -> bool {
-        if c.cur > 0 {
-            c.cur -= 1;
-            true
-        } else {
-            c.cur = -1;
-            false
+        if c.cur < 0 {
+            return false;
         }
+        c.cur -= 1;
+        true
     }
 
-    // This is the first non-trivial method, let's explain it.
     fn current<'a, T: LoadPage>(
         _txn: &T,
         page: crate::Page<'a>,
@@ -170,10 +166,10 @@ impl<K: Storable, V: Storable> super::BTreePage<K, V> for Page<K, V> {
             // Else, if this is a leaf, the elements are packed
             // together in a contiguous array.
             //
-            // This means that the header may be followed by
-            // padding. These are constants known at compile-time, by
-            // the way, so `al` and `hdr` are optimised away by the
-            // compiler.
+            // This means that the header may be followed by padding
+            // (in order to align the entries). These are constants
+            // known at compile-time, so `al` and `hdr` are optimised
+            // away by the compiler.
             let al = core::mem::align_of::<Tuple<K, V>>();
 
             // The following is a way to compute the first multiple of
@@ -182,7 +178,8 @@ impl<K: Storable, V: Storable> super::BTreePage<K, V> for Page<K, V> {
             let hdr = (HDR + al - 1) & !(al - 1);
 
             // The position of the `Tuple<K, V>` we're looking for is
-            // `f * cur` bytes after the padded header:
+            // `f * cur` bytes after the padded header (because
+            // `size_of` includes alignment padding).
             let f = core::mem::size_of::<Tuple<K, V>>();
             let kv = unsafe {
                 &*(page.data.as_ptr().add(hdr + c.cur as usize * f) as *const Tuple<K, V>)
@@ -223,7 +220,7 @@ impl<K: Storable, V: Storable> super::BTreePage<K, V> for Page<K, V> {
         } else {
             assert!(c.cur >= 0 && HDR as isize + c.cur * 8 - 8 <= 4088);
             let off =
-                unsafe { *(page.data.as_ptr().add((HDR + c.cur as usize * 8) - 8) as *const u64) };
+                unsafe { *(page.data.as_ptr().offset((HDR as isize + c.cur * 8) - 8) as *const u64) };
             u64::from_le(off) & !0xfff
         }
     }
@@ -231,7 +228,7 @@ impl<K: Storable, V: Storable> super::BTreePage<K, V> for Page<K, V> {
         if c.is_leaf {
             0
         } else {
-            assert!(c.cur < c.total as isize && HDR as isize + c.cur * 8 - 8 <= 4088);
+            assert!(c.cur < c.total as isize && HDR as isize + c.cur * 8 <= 4088);
             let off =
                 unsafe { *(page.data.as_ptr().offset(HDR as isize + c.cur * 8) as *const u64) };
             u64::from_le(off) & !0xfff
@@ -254,8 +251,7 @@ impl<K: Storable, V: Storable> super::BTreePage<K, V> for Page<K, V> {
             match lookup(txn, page, c, k0, v0) {
                 Ok(n) => {
                     c.cur = n as isize;
-                    // Just read the tuple, as we did multiple times
-                    // before.
+                    // Just read the tuple and return it.
                     if c.is_leaf {
                         let f = core::mem::size_of::<Tuple<K, V>>();
                         let al = core::mem::align_of::<Tuple<K, V>>();
@@ -316,7 +312,7 @@ impl<K: Storable + core::fmt::Debug, V: Storable + core::fmt::Debug> super::BTre
     }
 
     // `put` inserts one or two entries onto a node (internal or
-    // leaf). This is implemented the `put` module.
+    // leaf). This is implemented in the `put` module.
     fn put<'a, T: AllocPage>(
         txn: &mut T,
         page: CowPage,
@@ -340,13 +336,7 @@ impl<K: Storable + core::fmt::Debug, V: Storable + core::fmt::Debug> super::BTre
         }
     }
 
-    unsafe fn put_mut(
-        page: &mut MutPage,
-        c: &mut Self::Cursor,
-        k0: &K,
-        v0: &V,
-        r: u64,
-    ) {
+    unsafe fn put_mut(page: &mut MutPage, c: &mut Self::Cursor, k0: &K, v0: &V, r: u64) {
         use super::page_unsized::AllocWrite;
         let mut n = c.cur;
         if r == 0 {
@@ -357,11 +347,7 @@ impl<K: Storable + core::fmt::Debug, V: Storable + core::fmt::Debug> super::BTre
         c.total += 1;
     }
 
-    unsafe fn set_left_child(
-        page: &mut MutPage,
-        c: &Self::Cursor,
-        l: u64
-    ) {
+    unsafe fn set_left_child(page: &mut MutPage, c: &Self::Cursor, l: u64) {
         let off = (page.0.data.add(HDR) as *mut u64).offset(c.cur - 1);
         *off = (l | (u64::from_le(*off) & 0xfff)).to_le();
     }
@@ -375,7 +361,7 @@ impl<K: Storable + core::fmt::Debug, V: Storable + core::fmt::Debug> super::BTre
         c: &Self::Cursor,
         l: u64,
     ) -> Result<crate::btree::put::Ok, T::Error> {
-        assert!(!c.is_leaf && c.cur >= 0 && (c.cur as usize) < c.total + 1);
+        assert!(!c.is_leaf && c.cur >= 0 && (c.cur as usize) <= c.total);
         let freed;
         let page = if mutable && page.is_dirty() {
             // If the page is mutable (dirty), just convert it to a
@@ -689,7 +675,11 @@ fn cmp<T: LoadPage, K: Storable, V: Storable>(
 ) -> Ordering {
     let off = u64::from_le(off) & 0xfff;
     if off as usize + core::mem::size_of::<Tuple<K, V>>() > PAGE_SIZE {
-        panic!("off = {:?}, size = {:?}", off, core::mem::size_of::<Tuple<K, V>>());
+        panic!(
+            "off = {:?}, size = {:?}",
+            off,
+            core::mem::size_of::<Tuple<K, V>>()
+        );
     }
     let tup = unsafe { &*(p.as_ptr().offset(off as isize & 0xfff) as *const Tuple<K, V>) };
     match tup.k.compare(txn, k0) {
