@@ -339,7 +339,7 @@ impl<
 
     unsafe fn put_mut(
         page: &mut MutPage,
-        c: &Self::Cursor,
+        c: &mut Self::Cursor,
         k0: &K,
         v0: &V,
         r: u64,
@@ -350,6 +350,7 @@ impl<
         } else {
             Internal::alloc_write(page, k0, v0, 0, r, &mut n);
         }
+        c.total += 1;
     }
 
     unsafe fn set_left_child(
