@@ -1,6 +1,7 @@
 //! Insertions into a B tree.
 use super::cursor::*;
 use super::*;
+
 /// The representation of the update to a page.
 #[derive(Debug)]
 pub struct Ok {
@@ -28,8 +29,8 @@ pub enum Put<'a, K: ?Sized, V: ?Sized> {
 /// database.
 pub fn put<
     T: AllocPage,
-    K: Storable + ?Sized + core::fmt::Debug,
-    V: Storable + ?Sized + core::fmt::Debug,
+    K: Storable + ?Sized,
+    V: Storable + ?Sized,
     P: BTreeMutPage<K, V>,
 >(
     txn: &mut T,
@@ -97,8 +98,8 @@ pub fn put<
 
 fn put_cascade<
     T: AllocPage,
-    K: Storable + ?Sized + core::fmt::Debug,
-    V: Storable + ?Sized + core::fmt::Debug,
+    K: Storable + ?Sized,
+    V: Storable + ?Sized,
     P: BTreeMutPage<K, V>,
 >(
     txn: &mut T,
