@@ -65,7 +65,7 @@ pub trait Storable: core::fmt::Debug {
 
 /// A macro to implement [`Storable`] on "plain" types,
 /// i.e. fixed-sized types that are `repr(C)` and don't hold
-/// references to out-of-tree pages.
+/// references.
 #[macro_export]
 macro_rules! direct_repr {
     ($t: ty) => {
@@ -135,8 +135,6 @@ direct_repr!(uuid::Uuid);
 #[cfg(feature = "ed25519")]
 direct_repr!(ed25519_zebra::VerificationKeyBytes);
 
-
-
 /// Types that can be stored on disk.
 pub trait UnsizedStorable: Storable {
     const ALIGN: usize;
@@ -202,10 +200,10 @@ unsafe fn read<T: LoadPage, K: UnsizedStorable + ?Sized, V: UnsizedStorable + ?S
 unsafe fn entry_size<K: UnsizedStorable + ?Sized, V: UnsizedStorable + ?Sized>(
     k: *const u8,
 ) -> usize {
+    assert_eq!(k.align_offset(K::ALIGN), 0);
     let ks = K::onpage_size(k);
     // next multiple of va, assuming va is a power of 2.
-    let va = V::ALIGN;
-    let v_off = (ks + va - 1) & !(va - 1);
+    let v_off = (ks + V::ALIGN - 1) & !(V::ALIGN - 1);
     let v_ptr = k.add(v_off);
     let vs = V::onpage_size(v_ptr);
     let ka = K::ALIGN.max(V::ALIGN);
@@ -253,9 +251,12 @@ impl CowPage {
         // Hash the beginning and the end of the page (i.e. remove
         // the CRC).
         unsafe {
-            hasher.update(core::slice::from_raw_parts(self.data, 4));
+            // Remove the dirty bit.
+            let x = [(*self.data) & 0xfe];
+            hasher.update(&x[..]);
+            hasher.update(core::slice::from_raw_parts(self.data.add(1), 3));
             hasher.update(core::slice::from_raw_parts(
-                self.data.offset(8),
+                self.data.add(8),
                 PAGE_SIZE - 8,
             ));
         }
@@ -264,13 +265,13 @@ impl CowPage {
 
     #[cfg(feature = "crc32")]
     pub fn crc_check(&self, hasher: &crc32fast::Hasher) -> bool {
-        let crc = unsafe { u32::from_le(*(self.data as *const u32)) };
+        let crc = unsafe { u32::from_le(*(self.data as *const u32).add(1)) };
         self.crc(hasher) == crc
     }
 }
 
 /// An owned page on which we can write. This is just a wrapper around
-/// `CowPage` to avoid checking the "dirty" bit at running time.
+/// `CowPage` to avoid checking the "dirty" bit at runtime.
 #[derive(Debug)]
 pub struct MutPage(pub CowPage);
 
@@ -284,7 +285,7 @@ impl MutPage {
     pub fn clear_dirty(&mut self, hasher: &crc32fast::Hasher) {
         unsafe {
             *self.0.data &= 0xfe;
-            let crc = (self.0.data as *mut u32).offset(1);
+            let crc = (self.0.data as *mut u32).add(1);
             *crc = self.0.crc(hasher)
         }
     }
